============================
The ``lino_openui5`` package
============================




The SAP Open Ui5 user interface for Lino

The central project homepage is http://openui5.lino-framework.org/



